#ifndef NT2_INCLUDE_CONSTANTS_TWOPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWOPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/twopi.hpp>

#endif
